package com.yiqi.order.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.yiqi.order.domain.OrderRechargeRefund;

/**
 * 充值卡退款管理Service接口
 *
 * @author ruoyi
 * @date 2024-08-10
 */
public interface IOrderRechargeRefundService extends IService<OrderRechargeRefund> {

    //<editor-folder desc="基础函数">
    /**
     * 查询充值卡退款管理
     *
     * @param id 充值卡退款管理主键
     * @return 充值卡退款管理
     */
    public OrderRechargeRefund selectOrderRechargeRefundById(Long id);

    /**
     * 根据订单号查询充值卡退款管理
     * @param orderNo
     * @return
     */
    public OrderRechargeRefund selectOrderRechargeOrderNo(String orderNo);

    /**
     * 查询充值卡退款管理列表
     *
     * @param orderRechargeRefund 充值卡退款管理
     * @return 充值卡退款管理集合
     */
    public List<OrderRechargeRefund> selectOrderRechargeRefundList(OrderRechargeRefund orderRechargeRefund);

    /**
     * 新增充值卡退款管理
     *
     * @param orderRechargeRefund 充值卡退款管理
     * @return 结果
     */
    public int insertOrderRechargeRefund(OrderRechargeRefund orderRechargeRefund);

    /**
     * 修改充值卡退款管理
     *
     * @param orderRechargeRefund 充值卡退款管理
     * @return 结果
     */
    public int updateOrderRechargeRefund(OrderRechargeRefund orderRechargeRefund);

    /**
     * 批量删除充值卡退款管理
     *
     * @param ids 需要删除的充值卡退款管理主键集合
     * @return 结果
     */
    public int deleteOrderRechargeRefundByIds(Long[] ids);

    /**
     * 删除充值卡退款管理信息
     *
     * @param id 充值卡退款管理主键
     * @return 结果
     */
    public int deleteOrderRechargeRefundById(Long id);

    /**
     * 批量退款
     * @param orderRechargeRefund
     * @return
     */
    int refundRechargeNo(OrderRechargeRefund orderRechargeRefund);


    //</editor-folder>
}
