package com.yiqi.admin.controller.order;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.yiqi.common.constant.UrlConstants;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.yiqi.common.annotation.Log;
import com.yiqi.common.core.controller.BaseController;
import com.yiqi.common.core.domain.AjaxResult;
import com.yiqi.common.enums.BusinessType;
import com.yiqi.order.domain.OrderRechargeRefund;
import com.yiqi.order.service.IOrderRechargeRefundService;
import com.yiqi.common.utils.poi.ExcelUtil;
import com.yiqi.common.core.page.TableDataInfo;

/**
 * 充值卡退款管理Controller
 *
 * @author ruoyi
 * @date 2024-08-10
 */
@Api(tags = "管理后台 - 充值卡退款管理")
@RestController
@RequestMapping(UrlConstants.managerApi + "/recharge/refund")
public class OrderRechargeRefundController extends BaseController {
    @Autowired
    private IOrderRechargeRefundService orderRechargeRefundService;


    //<editor-folder desc="基础函数">
    /**
     * 查询充值卡退款管理列表
     */
    @PreAuthorize("@ss.hasPermi('order:refund:list')")
    @GetMapping("/list")
    @ApiOperation(value = "查询充值卡退款管理列表")
    public TableDataInfo list(OrderRechargeRefund orderRechargeRefund) {
        startPage();
        List<OrderRechargeRefund> list = orderRechargeRefundService.selectOrderRechargeRefundList(orderRechargeRefund);
        return getDataTable(list);
    }

    /**
     * 导出充值卡退款管理列表
     */
    @PreAuthorize("@ss.hasPermi('order:refund:export')")
    @Log(title = "充值卡退款管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ApiOperation(value = "导出充值卡退款管理列表")
    public void export(HttpServletResponse response, OrderRechargeRefund orderRechargeRefund) {
        List<OrderRechargeRefund> list = orderRechargeRefundService.selectOrderRechargeRefundList(orderRechargeRefund);
        ExcelUtil<OrderRechargeRefund> util = new ExcelUtil<OrderRechargeRefund>(OrderRechargeRefund. class);
        util.exportExcel(response, list, "充值卡退款管理数据");
    }

    /**
     * 获取充值卡退款管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('order:refund:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation(value = "获取充值卡退款管理详细信息")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(orderRechargeRefundService.selectOrderRechargeRefundById(id));
    }

    /**
     * 新增充值卡退款管理
     */
    @PreAuthorize("@ss.hasPermi('order:refund:add')")
    @Log(title = "充值卡退款管理", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation(value = "新增充值卡退款管理")
    public AjaxResult add(@RequestBody OrderRechargeRefund orderRechargeRefund) {
        orderRechargeRefund.setCreateById(getUserId());
        orderRechargeRefund.setCreateBy(getUsername());
        return toAjax(orderRechargeRefundService.insertOrderRechargeRefund(orderRechargeRefund));
    }

    /**
     * 修改充值卡退款管理
     */
    @PreAuthorize("@ss.hasPermi('order:refund:edit')")
    @Log(title = "充值卡退款管理", businessType = BusinessType.UPDATE)
    @PutMapping
    @ApiOperation(value = "修改充值卡退款管理")
    public AjaxResult edit(@RequestBody OrderRechargeRefund orderRechargeRefund) {
        orderRechargeRefund.setUpdateById(getUserId());
        orderRechargeRefund.setUpdateBy(getUsername());
        return toAjax(orderRechargeRefundService.updateOrderRechargeRefund(orderRechargeRefund));
    }

    /**
     * 删除充值卡退款管理
     */
    @PreAuthorize("@ss.hasPermi('order:refund:remove')")
    @Log(title = "充值卡退款管理", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    @ApiOperation(value = "删除充值卡退款管理")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(orderRechargeRefundService.deleteOrderRechargeRefundByIds(ids));
    }


    //</editor-folder>
}
